/**
 * Field class.
 *
 * @since 1.0.0
 */
export default class CSSElement {
    /**
     * Classes.
     *
     * @type string[]
     *
     * @since 1.0.0
     */
    classes = [];
    /**
     * Add Class.
     *
     * @param string Name of css class to add.
     *
     * @since 1.0.0
     */
    addClass(name) {
        if (this.classes.indexOf(name) !== -1) {
            return;
        }
        this.classes.push(name);
    }
    /**
     * Remove Class.
     *
     * @param string Name of css class to remove.
     *
     * @since 1.0.0
     */
    removeClass(name) {
        this.classes = this.classes.filter(className => className !== name);
    }
    /**
     * Get CSS Classes.
     *
     * @return String of CSS classes.
     *
     * @since 1.0.0
     */
    getClasses() {
        return this.classes.join(' ');
    }
}
