import type Form from './Form';
import type HasFieldsetData from '../Interfaces/HasFieldsetData';
import type HasConditionData from '../Interfaces/HasConditionData';
import Field from './Field';
import type HasSubmissionData from '../Interfaces/HasSubmissionData';
import CSSElement from './CSSElement';
/**
 * Class Fieldset.
 *
 * @since 1.0.0
 */
export default class Fieldset extends CSSElement {
    readonly form: Form;
    readonly name: string;
    readonly label: string;
    readonly percentage: number;
    readonly params: [];
    readonly conditions: HasConditionData[];
    readonly submission: HasSubmissionData | undefined;
    readonly nextFieldset: string;
    readonly prevFieldset: string;
    readonly fields: Field[];
    /**
     * @param fieldset Fieldset data.
     * Initializing fieldset.
     *
     * @param form Form object.
     *
     * @since 1.0.0
     */
    constructor(form: Form, fieldset: HasFieldsetData);
    /**
     * Checks if conditions are fullfilled.
     *
     * @returns True if conditions are fullfilled, false if not.
     *
     * @since 1.0.0
     */
    conditionsFullfilled(): boolean;
    /**
     * Get a specific field.
     *
     * @param name Name of field.
     * @return Field object. Undefined if nothing was found.
     *
     * @since 1.0.0
     */
    getField(name: string): Field;
    /**
     * Validate fieldset.
     *
     * @return True on successful validation, false on errors.
     *
     * @since 1.0.0
     */
    validate(): boolean;
    /**
     * Has fieldset validation errors.
     *
     * @return True if fieldset has errors, false if not.
     *
     * @since 1.0.0
     */
    hasValidationErrors(): boolean;
}
