import type HasFormData from '../Interfaces/HasFormData';
import type Field from './Field';
import Fieldset from './Fieldset';
import Navigation from './Navigation';
import CSSElement from './CSSElement';
/**
 * Class Form.
 *
 * @since 1.0.0
 */
export default class Form extends CSSElement {
    readonly name: string;
    readonly navigation: Navigation;
    readonly fieldsets: Fieldset[];
    /**
     * Initializing form data.
     *
     * @param formData Formdata from JSON file.
     *
     * @since 1.0.0
     */
    constructor(formData: HasFormData);
    /**
     * Get a specific fieldset.
     *
     * @param name Name of fieldset
     * @return Fieldset
     *
     * @since 1.0.0
     */
    getFieldset(name: string): Fieldset;
    /**
     * Get a specific field.
     *
     * @param name Name of field.
     * @return Field object. Undefined if nothing was found.
     *
     * @since 1.0.0
     */
    getField(name: string): Field;
    /**
     * Has form validation errors.
     *
     * @return True if field has errors, false if not.
     *
     * @since 1.0.0
     */
    hasValidationErrors(): boolean;
}
