import Fieldset from './Fieldset';
import Navigation from './Navigation';
import CSSElement from './CSSElement';
/**
 * Class Form.
 *
 * @since 1.0.0
 */
export default class Form extends CSSElement {
    name;
    navigation;
    fieldsets;
    /**
     * Initializing form data.
     *
     * @param formData Formdata from JSON file.
     *
     * @since 1.0.0
     */
    constructor(formData) {
        super();
        this.name = formData.name;
        this.fieldsets = [];
        this.addClass('needs-validation'); // BS5 class
        formData.classes?.forEach(className => this.addClass(className));
        formData.fieldsets.forEach(fieldset => this.fieldsets.push(new Fieldset(this, fieldset)));
        this.navigation = new Navigation(this, formData.start);
    }
    /**
     * Get a specific fieldset.
     *
     * @param name Name of fieldset
     * @return Fieldset
     *
     * @since 1.0.0
     */
    getFieldset(name) {
        let foundFieldset;
        this.fieldsets.forEach((fieldset) => {
            if (fieldset.name === name) {
                foundFieldset = fieldset;
            }
        });
        return foundFieldset;
    }
    /**
     * Get a specific field.
     *
     * @param name Name of field.
     * @return Field object. Undefined if nothing was found.
     *
     * @since 1.0.0
     */
    getField(name) {
        let foundField;
        this.fieldsets.forEach((fieldset) => {
            let field = fieldset.getField(name);
            if (field !== undefined) {
                foundField = field;
            }
        });
        return foundField;
    }
    /**
     * Has form validation errors.
     *
     * @return True if field has errors, false if not.
     *
     * @since 1.0.0
     */
    hasValidationErrors() {
        this.fieldsets.forEach((fieldset) => {
            if (fieldset.hasValidationErrors()) {
                return true;
            }
        });
        return false;
    }
}
