import type Fieldset from "./Fieldset";
import type Form from "./Form";
export default class Navigation {
    readonly form: Form;
    private currentFieldset;
    private recentFieldsets;
    private lastAction;
    /**
     * Initializing navigation.
     *
     * @param form  Form object.
     * @param start Name of start fieldset.
     *
     * @since 1.0.0
     */
    constructor(form: Form, startFieldset: string);
    /**
     * Get last action.
     *
     * @return Last action (prev or next).
     *
     * @since 1.0.0
     */
    getLastAction(): string;
    /**
     * Set current fieldset.
     *
     * @param name Name of fieldset.
     *
     * @since 1.0.0
     */
    setCurrentFieldset(name: string): Navigation;
    /**
     * Get current fieldset.
     *
     * @return Current fieldset.
     *
     * @since 1.0.0
     */
    getCurrentFieldset(): Fieldset;
    /**
     * Set previous fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    prevFieldset(): Navigation;
    /**
     * Set next fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    nextFieldset(): Navigation;
    /**
     * Is there a previous fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasPrevFieldset(): boolean;
    /**
     * Is there a next fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasNextFieldset(): boolean;
    /**
     * Returns the next fieldset.
     *
     * @return Next fieldset object.
     *
     * @since 1.0.0
     */
    getNextFieldset(): Fieldset;
    /**
     * Returns the previous fieldset.
     *
     * @return Previous fieldset object.
     *
     * @since 1.0.0
     */
    getPrevFieldset(): Fieldset;
    /**
     * Returns a possible fieldsets.
     *
     * Possible fieldsets are all fieldsets which containing a prevFieldset, containing the current fieldset.
     *
     * @return An array of Fieldsets.
     *
     * @since 1.0.0
     */
    private getPossibleNextFieldsets;
}
